@@ -11,7 +11,6 @@ from .exceptions import KempTechApiException, CommandNotAvailableException
 from .exceptions import ConnectionTimeoutException
 
 
-
 requests.packages.urllib3.disable_warnings()
 log = logging.getLogger(__name__)
 
@@ -149,16 +148,20 @@ class BaseObjectModel(HttpClient):
 class LoadMaster(HttpClient):
     """LoadMaster API object."""
 
-    def __init__(self, ip, username, password):
+    def __init__(self, ip, username, password, port=443):
         self.ip_address = ip
         self.username = username
         self.password = password
+        self.port = port
 
     @property
     def endpoint(self):
-        return "https://{user}:{pw}@{ip}/access".format(user=self.username,
-                                                        pw=self.password,
-                                                        ip=self.ip_address)
+        return "https://{user}:{pw}@{ip}:{port}/access".format(
+            user=self.username,
+            pw=self.password,
+            ip=self.ip_address,
+            port=self.port
+        )
 
     def set_parameter(self, parameter, value):
         parameters = {
@@ -190,7 +193,7 @@ class LoadMaster(HttpClient):
                                                            pw=self.password,
                                                            ip=self.ip_address)
         try:
-            requests.get(url, verify=False)
+            requests.get(url, verify=False, timeout=1)
             return True
         except exceptions.RequestException:
             return False
